@@ -53,7 +53,7 @@ class Flow(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["FlowProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[FlowProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -226,7 +226,7 @@ class RosFlow(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosFlowProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosFlowProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -564,7 +564,7 @@ class RosSchedule(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosScheduleProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosScheduleProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -938,7 +938,7 @@ class Schedule(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["ScheduleProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[ScheduleProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
